@@ -636,6 +636,24 @@ class A3Behavior extends Behavior {
     public final void rollLeftNow(double deg) {
         mulQuatImmediately(Util.euler2quat(0,0,-deg/180.0*Math.PI));
     }
+    public final void turnTo(double dirX, double dirY, double dirZ) {
+        Vector3d dir = new Vector3d(dirX,dirY,dirZ);
+        turnTo(dir);
+    }
+    public final void turnTo(Vector3d dir) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(nowV,dir);
+        setLookAtPoint(lookAtPoint);
+    }
+    public final void turnToNow(double dirX, double dirY, double dirZ) {
+        Vector3d dir = new Vector3d(dirX,dirY,dirZ);
+        turnToNow(dir);
+    }
+    public final void turnToNow(Vector3d dir) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(nowV,dir);
+        setLookAtPointImmediately(lookAtPoint);
+    }
 
     Vector3d getUnitVecX() {
         return Util.trans(nowQ,new Vector3d(1.0,0.0,0.0));
