@@ -2395,4 +2395,182 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         else
             throw new IllegalArgumentException();
     }
+    @Override
+    public void turnCameraTo(double dirX,double dirY,double dirZ) {
+        scene.turnCameraTo(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir) {
+        scene.turnCameraTo(dir);
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ) {
+        scene.turnCameraToNow(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir) {
+        scene.turnCameraToNow(dir);
+    }
+
+
+
+
+
+    @Override
+        public void turnCameraTo(double dirX,double dirY,double dirZ,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraTo(dirX,dirY,dirZ);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraTo(dir);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraToNow(dirX,dirY,dirZ);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.turnCameraToNow(dir);
+        else
+            throw new IllegalArgumentException();
+    }
+    //****************************************
+    @Override
+    public void setCameraLookAtPoint(A3Object a) {
+        scene.setCameraLookAtPoint(a);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up) {
+        scene.setCameraLookAtPoint(a,up);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(a);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPoint(a,up);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a) {
+        scene.setCameraLookAtPointNow(a);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up) {
+        scene.setCameraLookAtPointNow(a,up);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointNow(a);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.setCameraLookAtPointNow(a,up);
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public ArrayList<A3Object> getAll() {
+        return scene.getAll();
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c) {
+        return scene.getAll(c);
+    }
+    @Override
+    public ArrayList<A3Object> getAll(int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            return s.getAll();
+        else
+            throw new IllegalArgumentException();
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            return s.getAll(c);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    //2015,12/06: 指定したA3Objectの情報をもとにカメラを
+    //コントロールするメソッド達
+    @Override public void setCameraLoc(A3Object a)
+    {setCameraLoc(a.getLoc());}
+    @Override public void setCameraQuat(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraRev(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraScale(A3Object a)
+    {setCameraScale(a.getScale());}
+    @Override public void setCameraLocRevScale(A3Object a)
+    {setCameraLoc(a.getLoc());
+     setCameraQuat(a.getQuat());
+     setCameraScale(a.getScale());}
+    @Override public void setCameraLocNow(A3Object a)
+    {setCameraLocNow(a.getLoc());}
+    @Override public void setCameraQuatNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraRevNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraScaleNow(A3Object a)
+    {setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLocRevScaleNow(A3Object a)
+    {setCameraLocNow(a.getLoc());
+     setCameraQuatNow(a.getQuat());
+     setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLoc(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);}
+    @Override public void setCameraQuat(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraRev(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraScale(A3Object a,int scene)
+    {setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocRevScale(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);
+     setCameraQuat(a.getQuat(),scene);
+     setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);}
+    @Override public void setCameraQuatNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraRevNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraScaleNow(A3Object a,int scene)
+    {setCameraScaleNow(a.getScale(),scene);}
+    @Override public void setCameraLocRevScaleNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);
+     setCameraQuatNow(a.getQuat(),scene);
+     setCameraScaleNow(a.getScale(),scene);}
+
 }
