@@ -4,7 +4,7 @@ import java.io.*;
 import java.net.*;
 import javax.media.j3d.*;
 import javax.vecmath.*;
-
+import java.util.ArrayList;
 import jp.sourceforge.acerola3d.A23;
 import jp.sourceforge.acerola3d.SoftRefMap;
 
@@ -65,7 +65,7 @@ public class Action3D extends A3Object implements ActionObject {
      * A3InitDataの引数の数は、2か5か7か8でなければなりません。
      * 引数が5か7の時は自動的にautoActionControl=trueとなります。
      *
-     * <table border="1">
+     * <table border="1" summary="required data in A3InitData">
      * <tr><td>0:String      </td><td>URL of Acerola3D</td><td>必須</td></tr>
      * <tr><td>1:Serializable</td><td>ActionID        </td><td>必須</td></tr>
      * <tr><td>2:Serializable</td><td>haltActionID </td><td>任意</td></tr>
@@ -159,7 +159,7 @@ public class Action3D extends A3Object implements ActionObject {
      *
      * A3UpdateDataにセットするデータは以下のようになります。
      *
-     * <table border="1">
+     * <table border="1" summary="required data in A3UpdateData">
      * <tr><td>0:Serializable</td><td>ActionNo   </td><td>必須(変更なしの時は-1にする)</td></tr>
      * <tr><td>1:boolean     </td><td>immediately</td><td>必須</td></tr>
      * </table>
@@ -318,6 +318,14 @@ public class Action3D extends A3Object implements ActionObject {
         actionBehavior.setPauseTime(t);
     }
 
+    /**
+     * 現在再生中のアクションの再生開始からの時間を
+     * 取得します。
+     */
+    public double getTime() {
+        return actionBehavior.getTime();
+    }
+
     /**
      * オートアクションコントロールの機能の
      * ON、OFFを設定する。ONにすると移動の
@@ -520,6 +528,110 @@ public class Action3D extends A3Object implements ActionObject {
         actionBehavior.setMotion(action,motion);
     }
 
+    /**
+     * アクションに設定されているモーションデータを取得。
+     */
+    public Motion getMotion(int actionNo) {
+        return actionBehavior.getMotion(actionNo);
+    }
+
+    /**
+     * アクションに設定されているモーションデータを取得。
+     */
+    public Motion getMotion(Serializable action) {
+        return actionBehavior.getMotion(action);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションのスケール(scale)を
+     * 返します．
+     */
+    public double getActionScale(int actionNo) {
+        return actionBehavior.getActionScale(actionNo);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションのスケール(scale)を
+     * 返します．
+     */
+    public double getActionScale(Serializable action) {
+        return actionBehavior.getActionScale(action);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションのオフセット(offset)を
+     * 返します．
+     */
+    public Vector3d getActionOffset(int actionNo) {
+        return actionBehavior.getActionOffset(actionNo);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションのオフセット(offset)を
+     * 返します．
+     */
+    public Vector3d getActionOffset(Serializable action) {
+        return actionBehavior.getActionOffset(action);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションの回転(rot)を
+     * 返します．
+     */
+    public Vector3d getActionRot(int actionNo) {
+        return actionBehavior.getActionRot(actionNo);
+    }
+
+    /**
+     * CATALOG.XMLで指定されているアクションの回転(rot)を
+     * 返します．
+     */
+    public Vector3d getActionRot(Serializable action) {
+        return actionBehavior.getActionRot(action);
+    }
+
+    /**
+     * 現在再生中のアクションに含まれるBoneが世界座標系で
+     * 見て，どのような変換で表示されているかを示すTransform3Dを
+     * 返すメソッドです．
+     */
+    public Transform3D getWorldTransOfBone(String bone) {
+        String actionName = this.getActionName();
+
+        double actionScale = this.getActionScale(actionName);
+        Vector3d actionOffset = this.getActionOffset(actionName);
+        Vector3d actionRot = this.getActionRot(actionName);
+
+        Motion motion = this.getMotion(actionName);
+        ArrayList<String> al = new ArrayList<String>();
+        String b = bone;
+        while (b!=null) {
+            al.add(0,b);
+            b = motion.getParentBone(b);
+        }
+        String[] bones = al.toArray(new String[0]);
+
+        Quat4d quat = new Quat4d();
+        Vector3d loc = new Vector3d();
+        double scale;
+
+        Transform3D t2 = new Transform3D();//CATALOG.XMLの修正分
+        t2.set(Util.euler2quat(actionRot),actionOffset,actionScale);
+
+        Transform3D t1 = new Transform3D(this.getQuat(),this.getLoc(),this.getScale());
+        Transform3D t3 = new Transform3D();
+        double time = getTime();
+        for (int i=0;i<bones.length;i++) {
+            t3.mul(motion.getTransform3D(bones[i],time));
+        }
+        scale = t3.get(quat,loc);
+        t3.set(quat,loc,scale/actionScale);//美しくない．．．
+        t1.mul(t2);
+        t1.mul(t3);
+
+        return t1;
+    }
+
     /**
      * Shapeをあるアクションのボーンに設定。
      * このメソッドが上手く機能するためには、このAction3Dオブジェクトが
