@@ -608,4 +608,33 @@ class SubCameraBehavior extends Behavior {
     public final void rollCameraLeftNow(double deg) {
         mulCameraQuatImmediately(Util.euler2quat(0,0,deg/180.0*Math.PI));
     }
+    //****************************************
+    public void setCameraLookAtPoint(A3Object a,Vector3d up) {
+        this.setCameraLookAtPoint(a.getLoc(),up);
+    }
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up) {
+        this.setCameraLookAtPointImmediately(a.getLoc(),up);
+    }
+    public ArrayList<A3Object> getAll() {
+        return null;
+    }
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c) {
+        return null;
+    }
+    public void turnCameraTo(double dirX,double dirY,double dirZ,Vector3d up) {
+        turnCameraTo(new Vector3d(dirX,dirY,dirZ),up);
+    }
+    public void turnCameraTo(Vector3d dir,Vector3d up) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(cameraNowV,dir);
+        setCameraLookAtPoint(lookAtPoint,up);
+    }
+    public void turnCameraToNow(double dirX,double dirY,double dirZ,Vector3d up) {
+        turnCameraToNow(new Vector3d(dirX,dirY,dirZ),up);
+    }
+    public void turnCameraToNow(Vector3d dir,Vector3d up) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(cameraNowV,dir);
+        setCameraLookAtPointImmediately(lookAtPoint,up);
+    }
 }
