@@ -510,7 +510,7 @@ public class Util {
     }
     /**
      * 引数として与えられたjavax.media.j3d.Nodeに含まれる点の集合を
-     * com.bulletphysics.util.ObjectArrayList<Vector3f>で返します。
+     * com.bulletphysics.util.ObjectArrayList＜Vector3f＞で返します。
      */
     public static ObjectArrayList<Vector3f> listingVertexes(Node n) {
         ObjectArrayList<Vector3f> vertexes1 = new ObjectArrayList<Vector3f>();
@@ -908,6 +908,11 @@ public class Util {
         return bg;
     }
 
+    /**
+     * 引数で指定したミリ秒だけプログラムの実行を一時停止します．
+     * 内部でThread.sleep(long)を呼び出していますが，例外を
+     * 出さないようになっています．
+     */
     public static void sleep(long ms) {
         try {
             Thread.sleep(ms);
@@ -915,4 +920,96 @@ public class Util {
             e.printStackTrace();
         }
     }
+
+//----------------------------------------------------------
+
+    /**
+     * 引数で与えられたA3Objectのリストの中から
+     * pointに一番近い物を選び出して返します．
+     * 引数のA3Objectのリストが空の場合はnullがかえります．
+     */
+    public static A3Object getNearest(List<A3Object> objects,Vector3d point) {
+        double maxLen2 = Double.MAX_VALUE;
+        Vector3d tmp = new Vector3d();
+        A3Object ret = null;
+        for (A3Object o:objects) {
+            tmp.sub(point,o.getLoc());
+            if (maxLen2<tmp.lengthSquared()) {
+                ret = o;
+                maxLen2 = tmp.lengthSquared();
+            }
+        }
+        return ret;
+    }
+
+    /**
+     * 引数で与えられたA3Objectのリストの中から
+     * centerを中心とする半径radiusの球に含まれる物のみ選択しリストにして返します．
+     */
+    public static ArrayList<A3Object> objectsInSphere(List<A3Object> objects,Vector3d center,double radius) {
+        ArrayList<A3Object> ret = new ArrayList<A3Object>();
+        Vector3d tmp = new Vector3d();
+        double dd = radius*radius;
+        for (A3Object o:objects) {
+            tmp.sub(center,o.getLoc());
+            if (tmp.lengthSquared()<dd)
+                ret.add(o);
+        }
+        return ret;
+    }
+
+    /**
+     * 引数で与えられたA3Objectのリストの中から
+     * apexを頂点としdir方向にdeg度の角度で広がる円錐に含まれる物のみ選択し
+     * リストにして返します．
+     */
+    public static ArrayList<A3Object> objectsInCone(List<A3Object> objects,Vector3d apex,Vector3d dir,double deg) {
+        ArrayList<A3Object> ret = new ArrayList<A3Object>();
+        Vector3d dir2 = new Vector3d(dir);
+        dir2.normalize();
+        double dot = Math.cos(deg/180.0*Math.PI);
+        Vector3d tmp = new Vector3d();
+        for (A3Object o:objects) {
+            tmp.sub(o.getLoc(),apex);
+            if (tmp.lengthSquared()<0.000000001) continue;//ちょっと手抜き
+            tmp.normalize();
+            if (dir2.dot(tmp)>dot)
+                ret.add(o);
+        }
+        return ret;
+    }
+
+    class DistPack {
+        A3Object o;
+        double d;
+        DistPack(A3Object o,double d) {
+            this.o=o; this.d=d;
+        }
+    }
+    class DPComparator implements Comparator<DistPack> {
+        public int compare(DistPack a, DistPack b) {
+            if (a.d>b.d) return 1;
+            if (a.d==b.d) return 0;
+            return -1;
+        }
+    }
+    /**
+     * 与えられたA3Objectのリストをpointからの距離でソートします．
+     * 引数は変更されず，ソートされた返り値のリストは新たなリストとして生成されます．
+     */
+    public ArrayList<A3Object> sortByDistanceFromPoint(List<A3Object> objects,Vector3d point) {
+        ArrayList<DistPack> dps = new ArrayList<DistPack>();
+        Vector3d tmp = new Vector3d();
+        double d;
+        for (A3Object o:objects) {
+            tmp.sub(o.getLoc(),point);
+            dps.add(new DistPack(o,tmp.lengthSquared()));
+        }
+        Collections.sort(dps, new DPComparator());
+        ArrayList<A3Object> ret = new ArrayList<A3Object>();
+        for (DistPack dp:dps) {
+            ret.add(dp.o);
+        }
+        return ret;
+    }
 }
