@@ -23,7 +23,7 @@ class ParserBVH extends DepthFirstAdapter {
 
     public ParserBVH(URL url) throws Exception {
         InputStream is = url.openStream();
-        Reader reader = new InputStreamReader(is);
+        Reader reader = new InputStreamReader(is,"UTF-8");
         Lexer lexer = new Lexer(new PushbackReader(reader));
         Parser parser = new Parser(lexer);
         jp.sourceforge.acerola3d.a3.bvh.node.Node ast = parser.parse();
@@ -53,6 +53,8 @@ class ParserBVH extends DepthFirstAdapter {
 
     public String[] getChildBones(String b) {
         Bone bone = bones.get(b);
+        if (bone==null)
+            return new String[0];
         return bone.children.clone();
     }
 
@@ -61,6 +63,8 @@ class ParserBVH extends DepthFirstAdapter {
     }
     public Transform3D getTransform3D(String bone,double time) {
         Bone b = bones.get(bone);
+        if (b==null)
+            return null;
         int frame = (int)(time/frameTime);
         frame = (frame<0)?0:frame;
         frame = (frame>=frameCount)?frameCount-1:frame;
